@@ -299,6 +299,11 @@ ways, as listed at the top of each
 /* Compiler dependent options */
 #undef	NOENUM			/* Define if compiler has no enum's */
 #undef	NOSTRUCTASSIGN		/* Define if compiler can't assign structures */
+/* cfront 3.0 can't handle the assignments */
+#ifndef __GNUG__
+#define	NOSTRUCTASSIGN
+#endif
+
 
 /* define only one of the next two defines */
 #ifndef _G_SYSV
@@ -326,6 +331,7 @@ ways, as listed at the top of each
 
 
 #ifdef	NOSTRUCTASSIGN
+#include <string.h>
 #define	structassign(d, s)	memcpy(&(d), &(s), sizeof(d))
 #else
 #define	structassign(d, s)	d = s
@@ -691,15 +697,3 @@ boolean Func3(Enumeration	EnumParIn)
 	if (EnumLoc == Ident3) return (TRUE);
 	return (FALSE);
 }
-
-#ifdef	NOSTRUCTASSIGN
-memcpy(d, s, l)
-register char	*d;
-register char	*s;
-int	l;
-{
-	while (l--) *d++ = *s++;
-}
-#endif
-
-
