@@ -1,4 +1,5 @@
-#ifndef time_h
+#ifndef _G_time_h
+#define _G_time_h
 
 extern "C" {
 
