@@ -78,9 +78,9 @@ extern int      execl (const char*, const char *, ...);
 extern int      execle (const char*, const char *, ...);
 extern int      execlp (const char*, const char*, ...);
 extern int      exect _G_ARGS((const char*,  const char**,  char**));
-extern int      execv _G_ARGS((const char*,  const * char *));
-extern int      execve _G_ARGS((const char*, const * char *, char * const *));
-extern int      execvp _G_ARGS((const char*,  const * char *));
+extern int      execv _G_ARGS((const char*,  const char * const *));
+extern int      execve _G_ARGS((const char*, const char * const *, const char * const *));
+extern int      execvp _G_ARGS((const char*,  const char * const *));
 extern int      fchown (int, _G_uid_t, _G_gid_t);
 extern _G_pid_t fork _G_ARGS((void));
 extern int      fsync _G_ARGS((int));
@@ -111,7 +111,11 @@ extern int      pipe _G_ARGS((int*));
 extern int      readlink _G_ARGS((const char*, char*, int));
 extern int      rename _G_ARGS((const char*, const char*));
 extern int      rmdir _G_ARGS((const char*)); 
+#ifdef __OSF1__
+extern char*	sbrk _G_ARGS((int));
+#else
 extern void*    sbrk _G_ARGS((int)); 
+#endif
 extern int      syscall _G_ARGS((int, ...));
 extern int      setgid (_G_gid_t);
 extern int      sethostname _G_ARGS((const char*, int));
