@@ -26,9 +26,6 @@
 #ifdef _G_NEED_STDARG_H
 #include <stdarg.h>
 #endif
-#ifndef fpos_t
-#define fpos_t _G_fpos_t
-#endif
 
 #ifndef EOF
 #define EOF (-1)
@@ -430,7 +427,7 @@ class backupbuf : public streambuf {
 struct __file_fields {
     short _fileno;
     int _blksize;
-    fpos_t _offset;
+    _G_fpos_t _offset;
 //    char* _save_gptr;  char* _save_egptr;
 };
 
@@ -468,7 +465,7 @@ class filebuf : public backupbuf {
     int do_flush() { return do_write(_pbase, _pptr-_pbase); }
     // Low-level operations (Usually invoke system calls.)
     virtual _G_ssize_t sys_read(char* buf, _G_size_t size);
-    virtual fpos_t sys_seek(fpos_t, _seek_dir);
+    virtual _G_fpos_t sys_seek(_G_fpos_t, _seek_dir);
     virtual _G_ssize_t sys_write(const void*, long);
     virtual int sys_stat(void*); // Actually, a (struct stat*)
     virtual int sys_close();
