@@ -24,7 +24,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 #include <BitSet.h>
 #include <std.h>
-#include <values.h>
+#include <limits.h>
 #include <Obstack.h>
 #include <AllocRing.h>
 #include <new.h>
@@ -42,7 +42,7 @@ void BitSet::error(const char* msg) const
 BitSetRep  _nilBitSetRep = { 0, 1, 0, {0} }; // nil BitSets point here
 
 #define ONES               ((unsigned short)(~0L))
-#define MAXBitSetRep_SIZE  ((1 << (SHORTBITS - 1)) - 1)
+#define MAXBitSetRep_SIZE  ((1 << (sizeof(short)*CHAR_BIT - 1)) - 1)
 #define MINBitSetRep_SIZE  16
 
 #ifndef MALLOC_MIN_OVERHEAD
@@ -78,15 +78,15 @@ inline static BitSetRep* BSnew(int newlen)
     (*lib_error_handler)("BitSet", "Requested length out of range");
     
   BitSetRep* rep = (BitSetRep *) new char[allocsiz];
-  bzero(rep, allocsiz);
+  memset(rep, 0, allocsiz);
   rep->sz = (allocsiz - sizeof(BitSetRep) + sizeof(short)) / sizeof(short);
   return rep;
 }
 
-BitSetRep* BitSetalloc(BitSetRep* old, const unsigned short* src, int srclen, 
+BitSetRep* BitSetalloc(BitSetRep* old, const unsigned short* src, int srclen,
                 int newvirt, int newlen)
 {
-  if (old == &_nilBitSetRep) old = 0; 
+  if (old == &_nilBitSetRep) old = 0;
   BitSetRep* rep;
   if (old == 0 || newlen >= old->sz)
     rep = BSnew(newlen);
@@ -97,8 +97,10 @@ BitSetRep* BitSetalloc(BitSetRep* old, const unsigned short* src, int srclen,
   rep->virt = newvirt;
 
   if (srclen != 0 && src != rep->s)
-    bcopy(src, rep->s, srclen * sizeof(short));
-
+    memcpy(rep->s, src, srclen * sizeof(short));
+  // BUG fix: extend virtual bit! 20 Oct 1992 Kevin Karplus
+  if (rep->virt)
+      memset(&rep->s[srclen], ONES, (newlen - srclen) * sizeof(short));
   if (old != rep && old != 0) delete old;
   return rep;
 }
@@ -114,8 +116,11 @@ BitSetRep* BitSetresize(BitSetRep* old, int newlen)
   else if (newlen >= old->sz)
   {
     rep = BSnew(newlen);
-    bcopy(old->s, rep->s, old->len * sizeof(short));
+    memcpy(rep->s, old->s, old->len * sizeof(short));
     rep->virt = old->virt;
+    // BUG fix: extend virtual bit!  20 Oct 1992 Kevin Karplus
+    if (rep->virt)
+	memset(&rep->s[old->len], ONES, (newlen - old->len) * sizeof(short));
     delete old;
   }
   else
@@ -154,7 +159,7 @@ BitSetRep* BitSetcopy(BitSetRep* old, const BitSetRep* src)
     else
       rep = old;
 
-    bcopy(src->s, rep->s, newlen * sizeof(short));
+    memcpy(rep->s, src->s, newlen * sizeof(short));
     rep->len = newlen;
     rep->virt = src->virt;
   }
@@ -178,11 +183,32 @@ inline static void trim(BitSetRep* rep)
 
 int operator == (const BitSet& x, const BitSet& y)
 {
-  return x.rep->len == y.rep->len && x.rep->virt == y.rep->virt &&
-    bcmp((void*)x.rep->s, (void*)y.rep->s, 
-         x.rep->len * sizeof(short)) == 0;
-}
+  if (x.rep->virt != y.rep->virt)
+    return 0;
+  int xl = x.rep->len;
+  int yl = y.rep->len;
 
+  unsigned short* xs = x.rep->s;
+  unsigned short* ys = y.rep->s;
+  if (xl<=yl)
+    {
+      if (memcmp((void*)xs, (void*)ys, xl * sizeof(short)))
+  	return 0;
+      for (register int i=xl; i<yl; i++)
+        if (ys[i])
+	  return 0;
+      return 1;
+    }
+  else
+    {
+      if (memcmp((void*)xs, (void*)ys, yl * sizeof(short)))
+  	return 0;
+      for (register int i=yl; i<xl; i++)
+        if (xs[i]) 
+	  return 0;
+      return 1;
+    }
+}
 
 int operator <= (const BitSet& x, const BitSet& y)
 {
@@ -427,7 +453,7 @@ void BitSet::set(int p)
 
 void BitSet::clear()
 {
-  if (rep->len > 0) bzero(rep->s, rep->sz * sizeof(short));
+  if (rep->len > 0) memset(rep->s, 0, rep->sz * sizeof(short));
   rep->len = rep->virt = 0;
 }
 
