@@ -24,7 +24,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 #include <BitString.h>
 #include <std.h>
-#include <values.h>
+#include <limits.h>
 #include <Obstack.h>
 #include <AllocRing.h>
 #include <new.h>
@@ -43,7 +43,7 @@ BitStrRep    _nilBitStrRep = {  0, 1, {0} };
 BitString _nil_BitString;
 
 #define MINBitStrRep_SIZE  8
-#define MAXBitStrRep_SIZE  ((1 << (SHORTBITS - 1)) - 1)
+#define MAXBitStrRep_SIZE  ((1 << (sizeof(short)*CHAR_BIT - 1)) - 1)
 
 #ifndef MALLOC_MIN_OVERHEAD
 #define MALLOC_MIN_OVERHEAD    4
@@ -148,7 +148,7 @@ static inline void bit_copy(const unsigned short* ss, unsigned short* ds,
   if (ss != ds)
   {
     int n = (unsigned)(nbits) / BITSTRBITS;
-    if (n > 0) bcopy((void*)ss, (void*)ds, n * sizeof(short));
+    if (n > 0) memmove((void*)ds, (const void*)ss, n * sizeof(short));
     unsigned short m = ONES << (nbits & (BITSTRBITS - 1));
     ds[n] = (ss[n] & ~m) | (ds[n] & m);
   }
@@ -159,7 +159,7 @@ static inline void bit_copy(const unsigned short* ss, unsigned short* ds,
 static inline void bit_clear(unsigned short* ds, int nbits)
 {
   int n = (unsigned)(nbits) / BITSTRBITS;
-  if (n > 0) bzero((void*)ds, n * sizeof(short));
+  if (n > 0) memset((void*)ds, 0, n * sizeof(short));
   ds[n] &= ONES << (nbits & (BITSTRBITS - 1));
 }
 
@@ -296,7 +296,7 @@ inline static BitStrRep* BSnew(int newlen)
     (*lib_error_handler)("BitString", "Requested length out of range");
     
   BitStrRep* rep = (BitStrRep *) new char[allocsiz];
-  bzero(rep, allocsiz);
+  memset(rep, 0, allocsiz);
   rep->sz = (allocsiz - sizeof(BitStrRep) + sizeof(short)) / sizeof(short);
   return rep;
 }
@@ -336,7 +336,7 @@ BitStrRep* BStr_resize(BitStrRep* old, int newlen)
   else if (news > old->sz)
   {
     rep = BSnew(newlen);
-    bcopy(old->s, rep->s, BitStr_len(old->len) * sizeof(short));
+    memcpy(rep->s, old->s, BitStr_len(old->len) * sizeof(short));
     delete old;
   }
   else
@@ -373,7 +373,7 @@ BitStrRep* BStr_copy(BitStrRep* old, const BitStrRep* src)
     else
       rep = old;
     
-    bcopy(src->s, rep->s, news * sizeof(short));
+    memcpy(rep->s, src->s, news * sizeof(short));
     rep->len = newlen;
   }
   check_last(rep);
@@ -384,7 +384,7 @@ BitStrRep* BStr_copy(BitStrRep* old, const BitStrRep* src)
 int operator == (const BitString& x, const BitString& y)
 {
   return x.rep->len == y.rep->len && 
-    bcmp((void*)x.rep->s, (void*)y.rep->s, 
+    memcmp((void*)x.rep->s, (void*)y.rep->s, 
          BitStr_len(x.rep->len) * sizeof(short)) == 0;
 }
 
@@ -1973,7 +1973,6 @@ extern AllocRing _libgxx_fmtq;
 
 void BitString::printon(ostream& os, char f, char t) const
 {
-  int wrksiz = length() + 2;
   unsigned int  xl = rep->len;
   const unsigned short* ptr = rep->s;
   register streambuf *sb = os.rdbuf();
@@ -1991,7 +1990,6 @@ const char* BitStringtoa(const BitString& x, char f, char t)
 {
   int wrksiz = x.length() + 2;
   char* fmtbase = (char *) _libgxx_fmtq.alloc(wrksiz);
-  char* fmt = fmtbase;
   ostrstream stream(fmtbase, wrksiz);
   
   x.printon(stream, f, t);
