@@ -89,7 +89,7 @@ static inline _Fix _new_Fix(uint16 len)
   if (siz <= 0) siz = 1;
   unsigned int allocsiz = (sizeof(_Frep) + (siz - 1) * sizeof(uint16));
   _Fix z = (_Fix)(new char[allocsiz]);
-  bzero(z, allocsiz);
+  memset(z, 0, allocsiz);
   z->len = len;
   z->siz = siz;
   z->ref = 1;
