@@ -31,13 +31,22 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <Integer.h>
 #include <std.h>
 #include <ctype.h>
-#include <math.h>
+#include <float.h>
 #include <limits.h>
+#include <math.h>
 #include <Obstack.h>
 #include <AllocRing.h>
 #include <new.h>
 #include <builtin.h>
 
+#ifndef HUGE_VAL
+#ifdef HUGE
+#define HUGE_VAL HUGE
+#else
+#define HUGE_VAL DBL_MAX
+#endif
+#endif
+
 /*
  Sizes of shifts for multiple-precision arithmetic.
  These should not be changed unless Integer representation
@@ -279,20 +288,22 @@ IntRep* Icopy(IntRep* old, const IntRep* src)
 // allocate & copy space for a long
 
 IntRep* Icopy_long(IntRep* old, long x)
+{
+  int newsgn = (x >= 0);
+  IntRep* rep = Icopy_ulong(old, newsgn ? x : -x);
+  rep->sgn = newsgn;
+  return rep;
+}
+
+IntRep* Icopy_ulong(IntRep* old, unsigned long x)
 {
   unsigned short src[SHORT_PER_LONG];
-  unsigned long u;
-  int newsgn;
-  if (newsgn = (x >= 0))
-    u = x;
-  else
-    u = -x;
   
   unsigned short srclen = 0;
-  while (u != 0)
+  while (x != 0)
   {
-    src[srclen++] = extract(u);
-    u = down(u);
+    src[srclen++] = extract(x);
+    x = down(x);
   }
 
   IntRep* rep;
@@ -305,19 +316,18 @@ IntRep* Icopy_long(IntRep* old, long x)
     rep = old;
 
   rep->len = srclen;
-  rep->sgn = newsgn;
+  rep->sgn = I_POSITIVE;
 
   scpy(src, rep->s, srclen);
 
   return rep;
-
 }
 
 // special case for zero -- it's worth it!
 
 IntRep* Icopy_zero(IntRep* old)
 {
-  if (old == 0)
+  if (old == 0 || STATIC_IntRep(old))
     return &_ZeroRep;
 
   old->len = 0;
@@ -408,14 +418,14 @@ int Iislong(const IntRep* rep)
 double Itodouble(const IntRep* rep)
 { 
   double d = 0.0;
-  double bound = HUGE / 2.0;
+  double bound = DBL_MAX / 2.0;
   for (int i = rep->len - 1; i >= 0; --i)
   {
     unsigned short a = I_RADIX >> 1;
     while (a != 0)
     {
       if (d >= bound)
-        return (rep->sgn == I_NEGATIVE) ? -HUGE : HUGE;
+        return (rep->sgn == I_NEGATIVE) ? -HUGE_VAL : HUGE_VAL;
       d *= 2.0;
       if (rep->s[i] & a)
         d += 1.0;
@@ -435,7 +445,7 @@ double Itodouble(const IntRep* rep)
 int Iisdouble(const IntRep* rep)
 {
   double d = 0.0;
-  double bound = HUGE / 2.0;
+  double bound = DBL_MAX / 2.0;
   for (int i = rep->len - 1; i >= 0; --i)
   {
     unsigned short a = I_RADIX >> 1;
@@ -460,7 +470,7 @@ double ratio(const Integer& num, const Integer& den)
   divide(num, den, q, r);
   double d1 = double(q);
  
-  if (d1 == HUGE || d1 == -HUGE || sign(r) == 0)
+  if (d1 >= DBL_MAX || d1 <= -DBL_MAX || sign(r) == 0)
     return d1;
   else      // use as much precision as available for fractional part
   {
@@ -562,9 +572,9 @@ int compare(const IntRep* x, long  y)
         if (diff == 0)
           diff = docmp(x->s, tmp, xl);
       }
+      if (xsgn == I_NEGATIVE)
+	diff = -diff;
     }
-    if (xsgn == I_NEGATIVE)
-      diff = -diff;
     return diff;
   }
 }
@@ -2305,7 +2315,7 @@ istream& operator >> (istream& s, Integer& y)
   s >> ws;
   if (!s.good())
   {
-    s.set(_fail);
+    s.set(ios::failbit);
     return s;
   }
   
@@ -2332,7 +2342,7 @@ istream& operator >> (istream& s, Integer& y)
         break;
     }
     else if (!know_base & !got_one && ch == '0')
-      base = 8;
+      base = 8, got_one = 1;
     else if (!know_base & !got_one && base == 8 && (ch == 'X' || ch == 'x'))
       base = 16;
     else if (base == 8)
@@ -2385,7 +2395,7 @@ istream& operator >> (istream& s, Integer& y)
   if (s.good())
     s.putback(ch);
   if (!got_one)
-    s.set(_fail);
+    s.set(ios::failbit);
 
   if (sgn == '-')
     y.negate();
