@@ -2,19 +2,21 @@
    Copyright (C) 1992 Free Software Foundation, Inc.
    Written by Fred Fish.  fnf@cygnus.com
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+This file is part of the libiberty library.
+Libiberty is free software; you can redistribute it and/or
+modify it under the terms of the GNU Library General Public
+License as published by the Free Software Foundation; either
+version 2 of the License, or (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
+Libiberty is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Library General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+You should have received a copy of the GNU Library General Public
+License along with libiberty; see the file COPYING.LIB.  If
+not, write to the Free Software Foundation, Inc., 675 Mass Ave,
+Cambridge, MA 02139, USA.  */
 
 #include "config.h"
 
@@ -31,6 +33,17 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #undef sys_errlist
 #endif
 
+/*  Routines imported from standard C runtime libraries. */
+
+#ifdef __STDC__
+#include <stddef.h>
+extern void *malloc (size_t size);				/* 4.10.3.3 */
+extern void *memset (void *s, int c, size_t n);			/* 4.11.6.1 */
+#else	/* !__STDC__ */
+extern char *malloc ();		/* Standard memory allocater */
+extern char *memset ();
+#endif	/* __STDC__ */
+
 #ifndef NULL
 #  ifdef __STDC__
 #    define NULL (void *) 0
@@ -43,8 +56,6 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #  define MAX(a,b) ((a) > (b) ? (a) : (b))
 #endif
 
-extern char *malloc ();
-
 /* Translation table for errno values.  See intro(2) in most UNIX systems
    Programmers Reference Manuals.
 
@@ -512,7 +523,7 @@ init_error_tables ()
       nbytes = num_error_names * sizeof (char *);
       if ((error_names = (char **) malloc (nbytes)) != NULL)
 	{
-	  (void) memset (error_names, 0, nbytes);
+	  memset (error_names, 0, nbytes);
 	  for (eip = error_table; eip -> name != NULL; eip++)
 	    {
 	      error_names[eip -> value] = eip -> name;
@@ -530,7 +541,7 @@ init_error_tables ()
       nbytes = num_error_names * sizeof (char *);
       if ((sys_errlist = (char **) malloc (nbytes)) != NULL)
 	{
-	  (void) memset (sys_errlist, 0, nbytes);
+	  memset (sys_errlist, 0, nbytes);
 	  sys_nerr = num_error_names;
 	  for (eip = error_table; eip -> name != NULL; eip++)
 	    {
